import React from 'react';
import { TodoList } from '../components/TodoList'
import './App.css';
import { data } from './data'

const Empty = () => {
  return (<div className="container">
    <div className="row">
      <p className="lightgray">No Items in the list</p>
    </div>
  </div>)
}
const Header = props => {
  const { handleChange, handleAdd, items, text} = props
  console.log(props)
  return (<div>
    <h3 className="apptitle">MY TO DO LIST</h3>
    <form className="row">
      <div className="col-md-3">
        <input type="text" className="form-control" onChange={(e) => handleChange(e)} value={text} />
      </div>
      <div className="col-md-3">
        <button className="btn btn-primary" onClick={(e) => handleAdd(e)} disabled={!text}>{"Add #" + (items.length + 1)}</button>
      </div>
    </form>
    <br />
  </div>
  )
}
const Body = props => {
  console.log(props)
  const { items } = props
  const isEmpty = !items.length
  if (isEmpty) {
    return (<Empty />)
  } else {
    return (<div className="row">
      <div className="col-md-3">
        <TodoList {...props} />
      </div>
    </div>)
  }
}
const Footer = props => {
  const {items, handleDelete } = props
  const isCompleted = items.filter(item => { return item.isCompleted })
  return (
    <div className="row">
      <button className="btn btn-danger btn-sm float-right" onClick={() => handleDelete()} hidden={!isCompleted.length}>delete completed</button>
    </div>)
}

class App extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      text: '', 
      items: []
    }
  }
  handleChange = e => {
    this.setState({text: e.target.value });
  }
  handleAdd = e => {
    e.preventDefault();
    if (!this.state.text) { return false } 
    const item = {id: new Date().getTime(), text: this.state.text, isCompleted: false}
    this.setState((state) => ({text: "", items: state.items.concat(item)}));
  }
  markAsCompleted = id => {
    let filtered = this.state.items.map(item => {
      if (item.id == id) { item.isCompleted = !item.isCompleted}
      return item
    })
    this.setState({ items: filtered })
  }
  handleDelete = () => {
    let filtered = this.state.items.filter(item => { return !item.isCompleted })
    this.setState({ items: filtered })
  }
  render() {
    return (
      <div className="container">
        <div className="col-md-12 offset-2">
          <Header {...this.state} handleChange={this.handleChange} handleAdd={this.handleAdd}/>
          <Body   {...this.state} markAsCompleted={this.markAsCompleted }/>
          <Footer {...this.state} handleDelete={this.handleDelete} />
        </div>
      </div>
    );
  }
}
export default App;
